DatePickerFieldConfig class

Configuration for a date picker field.

Inheritance

Constructors

DatePickerFieldConfig({required String name, required String label, FormFieldValidator<DateTime>? validator})

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validator FormFieldValidator<DateTime>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited